@@ -113,10 +113,10 @@ def create_segment_values(arrays: list) -> Tuple:
     colors = cm.get_cmap('YlGnBu', 256)
     newcolors = colors(np.linspace(0, 1, 256))
     # No data, model, both, observation
-    cmap = ListedColormap(['whitesmoke', 'khaki', newcolors[90], newcolors[140]])
+    cmap = ListedColormap(['white', 'khaki', newcolors[90], newcolors[140]])
     if len(np.unique(new_array)) < 4:
         # model, both, model comparison
-        cmap = ListedColormap(['whitesmoke', 'khaki', newcolors[90]])
+        cmap = ListedColormap(['white', 'khaki', newcolors[90]])
     return new_array, cmap
 
 
